==> gitlab-foss-v18.3.3.tar.bz2: gitlab-foss-v18.3.3/.gitlab/issue_templates/R&D Interlock Epic.md <==
## Executive Summary
[Brief description of the feature and its scope]

#### Engineering Assessment 

[Brief description of the engineering assessment of this candidate item.]

#### Dependencies
- Team dependencies: [List team dependencies]
- Epic/Issue dependencies: [Link to dependent epics/issues]
- External dependencies: [Any external dependencies]

#### DRIs
- **PM**: [Name] <!-- also add as assignee to this epic -->
- **EM**: [Name] <!-- also add as assignee to this epic -->
- **UX/PDM**: [Name] <!-- also add as assignee to this epic -->
- **Group(s)**: [Group name(s)] <!-- also add as label -->
- **Engineering Owner**: [Name]

#### Business Impact
- **Product motivation**: [Description]
- **Key customers**: [List of key customers]
- **ARR impact**: [Anticipated ARR impact]

#### Sizing and Funding (Optional)
- **Size**: [XS/S/M/L/XL]
- **Funding Status**: [Funded/Partially funded/Not funded]

---

### Hygiene Guidelines

_See additional details about this process at https://gitlab.com/groups/gitlab-org/-/wikis/R&D-Interlock-Process-Dashboard?#interlock-process_

##### :one: Pre-Interlock
- Update epic description with all relevant information
- Ensure all dependencies are identified
- Apply appropriate labels (see below)
- Update interlock status as discussions progress (via label)

##### :two: Post-Interlock
- Update health status weekly (via label)
- Document any newly identified risks or dependencies
- Link to implementation epics/issues as work begins
- Flag any scope or timeline changes immediately

<!-- 
Apply appropriate labels:
- [ ] Section (section::dev, section::ops, section::sec)
- [ ] Stage (devops::plan, devops::create, devops::verify, etc.)
- [ ] Group (group::product planning, group::project management, etc.)
- [ ] Priority (Product labels = Product Priority::P1, Product Priority::P2, Product Priority::P3, Engineering labels = Eng Priority::E1, Eng Priority::E2, Eng Priority::E3)
- [ ] Tier (GTM tier::Tier 1, GTM tier::Tier 2, GTM tier::Tier 3)
- [ ] Investment theme (Investment theme::Core-Devops, Investment theme::Security-Compliance, Investment theme::AI across SDLC)
- [ ] Platforms (platform: GitLab.com, platform: dedicated, platform: self-managed)
- [ ] Subscription tier (GitLab Ultimate, GitLab Premium, GitLab Free)
- [ ] Quarter (FY26 Q1, FY26 Q2, FY26 Q3, FY26 Q4)
- [ ] Pre-interlock status label (interlock status::New/Proposal in progress, interlock status::cancelled, etc)
- [ ] Post-interlock status label (R&D roadmap status::Executing, R&D roadmap status::Completed) 
- [ ] Post-interlock health (health::on track, health::needs attention, health::at risk)
-->

> [!warning] This is a confidential epic because it may contain customer information

/label ~"Interlock candidate" 
/confidential

==> gitlab-foss-v18.6.1.tar.bz2: gitlab-foss-v18.6.1/.gitlab/issue_templates/R&D Interlock Epic.md <==
## Executive Summary
[Brief description of the feature and its scope]

#### Customer Impact
- **Top Customers Impacted**: [List key enterprise customers impacted, including number of seats]
- **Migration Opportunity**: [Describe customer migration desires and current blockers]
- **Competitive Position**: [Outline strategic market opportunity and competitive landscape]

#### ARR Impact
- **Year/year revenue growth (FY26)**: [X% acceleration in moderate investment plan, Y% acceleration in ambitious plan]
- **Year/year revenue growth (FY27)**: [X% acceleration in moderate investment plan, Y% acceleration in ambitious plan]
- **Year/year revenue growth (FY28)**: [X% acceleration in moderate investment plan, Y% acceleration in ambitious plan]
- **FY26-FY28 Revenue Projection**: [$X+ over three years]

#### GTM Strategy
- **Target Audience**: [Describe ideal customer profile and size]
- **Positioning**: [List key value propositions and differentiators]
- **Sales Enablement**: [Outline materials and resources needed for sales teams]
- **Marketing**: [Detail marketing channels and content strategy for promotion]

#### Engineering Assessment 

[Brief description of the engineering assessment of this candidate item.]

#### Dependencies
- Team dependencies: [List team dependencies]
- Epic/Issue dependencies: [Link to dependent epics/issues]
- External dependencies: [Any external dependencies]

#### DRIs
- **PM**: [Name] <!-- also add as assignee to this epic -->
- **EM**: [Name] <!-- also add as assignee to this epic -->
- **UX/PDM**: [Name] <!-- also add as assignee to this epic -->
- **Group(s)**: [Group name(s)] <!-- also add as label -->
- **Engineering Owner**: [Name]

#### Business Impact
- **Product motivation**: [Description]
- **Key customers**: [List of key customers]
- **ARR impact**: [Anticipated ARR impact]

#### Sizing and Funding (Optional)
- **Size**: [XS/S/M/L/XL]
- **Funding Status**: [Funded/Partially funded/Not funded]

---

### Hygiene Guidelines

_See additional details about this process at https://gitlab.com/groups/gitlab-org/-/wikis/R&D-Interlock-Process-Dashboard?#interlock-process_

##### :one: Pre-Interlock
- Update epic description with all relevant information
- Ensure all dependencies are identified
- Apply appropriate labels (see below)
- Update interlock status as discussions progress (via label)

##### :two: Post-Interlock
- Update health status weekly (via label)
- Document any newly identified risks or dependencies
- Link to implementation epics/issues as work begins
- Flag any scope or timeline changes immediately

<!-- 
Apply appropriate labels:
- [ ] Section (section::dev, section::ops, section::sec)
- [ ] Stage (devops::plan, devops::create, devops::verify, etc.)
- [ ] Group (group::product planning, group::project management, etc.)
- [ ] Priority (Product labels = Product Priority::P1, Product Priority::P2, Product Priority::P3, Engineering labels = Eng Priority::E1, Eng Priority::E2, Eng Priority::E3)
- [ ] Tier (GTM tier::Tier 1, GTM tier::Tier 2, GTM tier::Tier 3)
- [ ] Investment theme (Investment theme::Core-Devops, Investment theme::Security-Compliance, Investment theme::AI across SDLC)
- [ ] Platforms (platform: GitLab.com, platform: dedicated, platform: self-managed)
- [ ] Subscription tier (GitLab Ultimate, GitLab Premium, GitLab Free)
- [ ] Quarter (FY26 Q1, FY26 Q2, FY26 Q3, FY26 Q4)
- [ ] Pre-interlock status label (interlock status::New/Proposal in progress, interlock status::cancelled, etc)
- [ ] Post-interlock status label (R&D roadmap status::Executing, R&D roadmap status::Completed) 
- [ ] Post-interlock health (health::on track, health::needs attention, health::at risk)
-->

> [!warning] This is a confidential epic because it may contain customer information

/label ~"Interlock candidate" 
/confidential
